@@ -560,7 +560,6 @@ class RequestsMock(object):
         self._registry = FirstMatchRegistry()
         self._calls.reset()
         self.passthru_prefixes = ()
-        self._patcher = None
 
     def add(
         self,
@@ -834,6 +833,8 @@ class RequestsMock(object):
     def start(self):
         if self._patcher:
             # we must not override value of the _patcher if already applied
+            # this prevents issues when one decorated function is called from
+            # another decorated function
             return
 
         def unbound_on_send(adapter, request, *a, **kwargs):
@@ -847,6 +848,10 @@ class RequestsMock(object):
             # prevent stopping unstarted patchers
             self._patcher.stop()
 
+            # once patcher is stopped, clean it. This is required to create a new
+            # fresh patcher on self.start()
+            self._patcher = None
+
         if not self.assert_all_requests_are_fired:
             return
 
@@ -888,7 +893,7 @@ __all__ = [
     "add",
     "add_callback",
     "add_passthru",
-    "assert_all_requests_are_fired",
+    "_deprecated_assert_all_requests_are_fired",
     "assert_call_count",
     "calls",
     "delete",
@@ -899,7 +904,7 @@ __all__ = [
     "HEAD",
     "options",
     "OPTIONS",
-    "passthru_prefixes",
+    "_deprecated_passthru_prefixes",
     "patch",
     "PATCH",
     "post",
@@ -913,15 +918,16 @@ __all__ = [
     "response_callback",
     "start",
     "stop",
-    "target",
+    "_deprecated_target",
     "upsert",
 ]
 
+# expose only methods and/or read-only methods
 activate = _default_mock.activate
 add = _default_mock.add
 add_callback = _default_mock.add_callback
 add_passthru = _default_mock.add_passthru
-assert_all_requests_are_fired = _default_mock.assert_all_requests_are_fired
+_deprecated_assert_all_requests_are_fired = _default_mock.assert_all_requests_are_fired
 assert_call_count = _default_mock.assert_call_count
 calls = _default_mock.calls
 delete = _default_mock.delete
@@ -932,7 +938,7 @@ head = _default_mock.head
 HEAD = _default_mock.HEAD
 options = _default_mock.options
 OPTIONS = _default_mock.OPTIONS
-passthru_prefixes = _default_mock.passthru_prefixes
+_deprecated_passthru_prefixes = _default_mock.passthru_prefixes
 patch = _default_mock.patch
 PATCH = _default_mock.PATCH
 post = _default_mock.post
@@ -946,5 +952,18 @@ reset = _default_mock.reset
 response_callback = _default_mock.response_callback
 start = _default_mock.start
 stop = _default_mock.stop
-target = _default_mock.target
+_deprecated_target = _default_mock.target
 upsert = _default_mock.upsert
+
+
+deprecated_names = ["assert_all_requests_are_fired", "passthru_prefixes", "target"]
+
+
+def __getattr__(name):
+    if name in deprecated_names:
+        warn(
+            f"{name} is deprecated. Please use 'responses.mock.{name}",
+            DeprecationWarning,
+        )
+        return globals()[f"_deprecated_{name}"]
+    raise AttributeError(f"module {__name__} has no attribute {name}")
